@@ -24,17 +24,25 @@ def get_entities(documents, client):
         print("Encountered exception. {}".format(err))
 
 
-def get_entities_for_category(entity_category):
+def get_entities_for_category(entities_base, entity_category):
     """
     :param entity_category: could be for instance 'Organization'
-    :return:
+    :param entities_base: entities as returned from azure, has all entities, from which entity_category will be filtered
+    :return: entities_filtered
+
+    Example:
+
+    entity_category = 'Product'
+    entities_base = [CategorizedEntity(text=Buches, category=Product, subcategory=None, confidence_score=0.86),
+                     CategorizedEntity(text=Mädelsabend, category=Event, subcategory=None, confidence_score=0.81)]
+    entities_filtered = '['Buches']'
     """
-    entities = ''
+    entities_filtered = ''
     try:
-        entities = [entity.text for entity in entities if entity.category == entity_category]
+        entities_filtered = [entity.text for entity in entities_base if entity.category == entity_category]
     except:
         pass
-    return entities
+    return entities_filtered
 
 
 def get_sentiment(client, documents):
